# Pyrocko plot Module

* `pyrocko.plot.automap` Quickly generate pretty maps using gmtpy's powers.
* `pyrocko.plot.beachball` Beachball visualisation for `matplotlib`.
* `pyrocko.plot.cake_plot` Plotting velocities models and ray paths.
* `pyrocko.plot.hudson` Generate hudson plots with this module.
* `pyrocko.plot.response` Plot the station's response's.

## GMTPy

`pyrocko.plot.gmtpy` With support for GMT5 pyrocko's gmtpy exposes GMT's neat mapping functions to Python 2/3.
